#!/bin/bash
#SBATCH -t48:00:00 ### set the time
#SBATCH --qos=large ## set the range your time demand is in (not mandatory)
#SBATCH -p smp ## set the node
#SBATCH -c 36
#SBATCH --job-name=APMG-33
#SBATCH --output=%x_%j.out
#SBATCH --mail-user=
#SBATCH --mail-type=END

module load bio/OBItools/3.0.0

######################################################
################ things to adjust ####################
######################################################
#data variables
DMS_OUT=/APMG-33_data_out
DMS=/tmp/APMG-33
# copy data to tmp
DATAPATH=/APMG-33_data
FORWARD=210602_NB501850_A_L1-4_APMG-33_R1.fastq
REVERSE=210602_NB501850_A_L1-4_APMG-33_R2.fastq
TAGFILE=$DATAPATH/APMG-33_tagfile.txt
ID=APMG-33_
#######################################################
#######################################################
# copy data files to tmp (on calculating node)
cp $DATAPATH/$FORWARD /tmp
cp $DATAPATH/$REVERSE /tmp
#
cp -r /arctborbryo.obidms /tmp
cp -r /gh_embl143.obidms /tmp

# set tmp variables
DATA1=/tmp/$FORWARD
DATA2=/tmp/$REVERSE
EMBL=/tmp/gh_embl143.obidms
ARC=/tmp/arctborbryo.obidms


# import data
srun obi import --fastq-input $DATA1 $DMS/${ID}reads1
srun obi import --fastq-input $DATA2 $DMS/${ID}reads2
# import tag file
srun obi import --ngsfilter-input $TAGFILE $DMS/${ID}tagfile
# align paired ends
srun obi alignpairedend -R $DMS/${ID}reads1 $DMS/${ID}reads2 $DMS/${ID}aligned_reads
# remove unaligned
srun obi grep -a mode:alignment $DMS/${ID}aligned_reads $DMS/${ID}good_sequences
# assign reads to tag combinations
srun obi ngsfilter -t $DMS/${ID}tagfile -u $DMS/${ID}unidentified_seqs $DMS/${ID}good_sequences $DMS/${ID}identified_sequences
# dereplicate sequences into unique sequences
srun obi uniq --merge sample $DMS/${ID}identified_sequences $DMS/${ID}dereplicated_sequences
# denoise data, only keep COUNT and merged_sample tags
srun obi annotate -k COUNT -k MERGED_sample $DMS/${ID}dereplicated_sequences $DMS/${ID}cleaned_metadata_sequences
# grep
srun obi grep -p "len(sequence)>=10 and sequence['COUNT']>=10" $DMS/${ID}cleaned_metadata_sequences $DMS/${ID}cleaned_10_metadata_sequences
# denoise data, clean from pcr/sequencing errors
srun obi clean -s MERGED_sample -r 0.05 -H $DMS/${ID}cleaned_10_metadata_sequences $DMS/${ID}cleaned_sequences
# taxonomic assignment to embl
srun obi clean_dms $EMBL
srun obi ecotag --taxonomy $EMBL/TAXONOMY/ncbi_tax_12_20 -R $EMBL/VIEWS/gh_embl143_db_97.obiview $DMS/${ID}cleaned_sequences $DMS/${ID}embl143_assigned_sequences
# reorder sequences
obi sort -k COUNT $DMS/${ID}embl143_assigned_sequences $DMS/${ID}embl143_assigned_sequences_sorted
# annonate lineage information
srun obi annotate --with-taxon-at-rank family --with-taxon-at-rank genus --with-taxon-at-rank species --taxonomy $EMBL/TAXONOMY/ncbi_tax_12_20 $DMS/${ID}embl143_assigned_sequences_sorted $DMS/${ID}embl143_annotated_sequences
# assign to arctborbryo
srun obi clean_dms $ARC
srun obi ecotag --taxonomy $ARC/TAXONOMY/ncbi_tax_12_20 -R $ARC/VIEWS/arctborbryo_db_97.obiview $DMS/${ID}cleaned_sequences $DMS/${ID}arc_assigned_sequences
# reorder sequences
obi sort -k COUNT $DMS/${ID}arc_assigned_sequences $DMS/${ID}arc_assigned_sequences_sorted
# annonate lineage information
srun obi annotate --with-taxon-at-rank family --with-taxon-at-rank genus --with-taxon-at-rank species --taxonomy $ARC/TAXONOMY/ncbi_tax_12_20 $DMS/${ID}arc_assigned_sequences_sorted $DMS/${ID}arc_annotated_sequences
# export embl assignment as csv file
srun obi export --header --tab-output $DMS/${ID}embl143_annotated_sequences > $DMS_OUT/${ID}embl143_anno.csv
# export arc assignment as csv file
srun obi export --header --tab-output $DMS/${ID}arc_annotated_sequences > $DMS_OUT/${ID}arc_anno.csv
# copy dms (all files of analysis) from calculating node to work folder
srun cp -r ${DMS}.obidms $DMS_OUT
